@@ -2,7 +2,7 @@
     This class provides the basic network item for the core library of
     Smb4K.
 
-    SPDX-FileCopyrightText: 2009-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2009-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -28,50 +28,41 @@ public:
 Smb4KBasicNetworkItem::Smb4KBasicNetworkItem(NetworkItem type)
     : d(new Smb4KBasicNetworkItemPrivate)
 {
-    //
-    // Set the type
-    //
     d->type = type;
-
-    //
-    // Initialize the dnsDiscovered variable
-    //
     d->dnsDiscovered = false;
 
-    //
-    // Initialize the protected variables
-    //
     pUrl = &d->url;
     pIcon = &d->icon;
     pComment = &d->comment;
+    pType = &d->type;
 }
 
 Smb4KBasicNetworkItem::Smb4KBasicNetworkItem(const Smb4KBasicNetworkItem &item)
     : d(new Smb4KBasicNetworkItemPrivate)
 {
-    //
-    // Copy the private variables
-    //
     *d = *item.d;
 
-    //
-    // Initialize the protected variables
-    //
     pUrl = &d->url;
     pIcon = &d->icon;
     pComment = &d->comment;
+    pType = &d->type;
 }
 
 Smb4KBasicNetworkItem::~Smb4KBasicNetworkItem()
 {
 }
 
+void Smb4KBasicNetworkItem::setType(Smb4KGlobal::NetworkItem type) const
+{
+    d->type = type;
+}
+
 Smb4KGlobal::NetworkItem Smb4KBasicNetworkItem::type() const
 {
     return d->type;
 }
 
-void Smb4KBasicNetworkItem::setIcon(const QIcon &icon)
+void Smb4KBasicNetworkItem::setIcon(const QIcon &icon) const
 {
     d->icon = icon;
 }
@@ -81,7 +72,7 @@ QIcon Smb4KBasicNetworkItem::icon() const
     return d->icon;
 }
 
-void Smb4KBasicNetworkItem::setUrl(const QUrl &url)
+void Smb4KBasicNetworkItem::setUrl(const QUrl &url) const
 {
     //
     // Check that the URL is valid
@@ -132,7 +123,7 @@ QUrl Smb4KBasicNetworkItem::url() const
     return d->url;
 }
 
-void Smb4KBasicNetworkItem::setDnsDiscovered(bool discovered)
+void Smb4KBasicNetworkItem::setDnsDiscovered(bool discovered) const
 {
     d->dnsDiscovered = discovered;
 }
@@ -142,7 +133,7 @@ bool Smb4KBasicNetworkItem::dnsDiscovered() const
     return d->dnsDiscovered;
 }
 
-void Smb4KBasicNetworkItem::setComment(const QString &comment)
+void Smb4KBasicNetworkItem::setComment(const QString &comment) const
 {
     d->comment = comment;
 }
@@ -156,3 +147,9 @@ bool Smb4KBasicNetworkItem::hasUserInfo() const
 {
     return !d->url.userInfo().isEmpty();
 }
+
+Smb4KBasicNetworkItem &Smb4KBasicNetworkItem::operator=(const Smb4KBasicNetworkItem &other)
+{
+    *d = *other.d;
+    return *this;
+}
