@@ -1,15 +1,13 @@
 /*
     This class handles the bookmarks.
 
-    SPDX-FileCopyrightText: 2004-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2004-2024 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 // application specific includes
 #include "smb4kbookmarkhandler.h"
 #include "smb4kbookmark.h"
-#include "smb4kglobal.h"
-#include "smb4khomesshareshandler.h"
 #include "smb4khost.h"
 #include "smb4knotification.h"
 #include "smb4kprofilemanager.h"
@@ -17,11 +15,9 @@
 #include "smb4kshare.h"
 
 // Qt includes
-#include <QApplication>
 #include <QDir>
 #include <QFile>
 #include <QMutableListIterator>
-#include <QPointer>
 #include <QTextStream>
 #include <QXmlStreamReader>
 #include <QXmlStreamWriter>
@@ -57,10 +53,11 @@ Smb4KBookmarkHandler::Smb4KBookmarkHandler(QObject *parent)
         dir.mkpath(path);
     }
 
-    readBookmarkList();
+    read();
 
     connect(Smb4KProfileManager::self(), &Smb4KProfileManager::profileRemoved, this, &Smb4KBookmarkHandler::slotProfileRemoved);
     connect(Smb4KProfileManager::self(), &Smb4KProfileManager::profileMigrated, this, &Smb4KBookmarkHandler::slotProfileMigrated);
+    connect(Smb4KProfileManager::self(), &Smb4KProfileManager::activeProfileChanged, this, &Smb4KBookmarkHandler::slotActiveProfileChanged);
 }
 
 Smb4KBookmarkHandler::~Smb4KBookmarkHandler()
@@ -77,179 +74,219 @@ Smb4KBookmarkHandler *Smb4KBookmarkHandler::self()
 
 void Smb4KBookmarkHandler::addBookmark(const BookmarkPtr &bookmark)
 {
-    if (bookmark) {
-        //
-        // Create a list that will be passed to addBookmarks()
-        //
-        QList<BookmarkPtr> bookmarks;
-
-        //
-        // Check if the share has already been bookmarked and skip it if it
-        // already exists
-        //
-        BookmarkPtr knownBookmark = findBookmarkByUrl(bookmark->url());
-
-        if (knownBookmark) {
-            Smb4KNotification::bookmarkExists(knownBookmark);
-            return;
-        }
-
-        //
-        // Copy the bookmark, add the correct profile (may be empty) and
-        // add it to the list.
-        //
-        BookmarkPtr newBookmark = BookmarkPtr(bookmark);
-        newBookmark->setProfile(Smb4KProfileManager::self()->activeProfile());
-        bookmarks << newBookmark;
-
-        //
-        // Add the bookmark
-        //
-        addBookmarks(bookmarks, false);
+    if (bookmark && add(bookmark)) {
+        write();
+        Q_EMIT updated();
     }
 }
 
 void Smb4KBookmarkHandler::addBookmarks(const QList<BookmarkPtr> &list, bool replace)
 {
-    //
-    // Process the incoming list.
-    // In case the internal list should be replaced, clear the internal
-    // list first.
-    //
     if (replace) {
         QMutableListIterator<BookmarkPtr> it(d->bookmarks);
 
         while (it.hasNext()) {
             BookmarkPtr bookmark = it.next();
-            removeBookmark(bookmark);
+
+            if (!Smb4KSettings::useProfiles() || bookmark->profile() == Smb4KSettings::activeProfile()) {
+                it.remove();
+                bookmark.clear();
+            }
         }
     }
 
-    //
-    // Copy all bookmarks that are not in the list
-    //
+    bool added = false;
+
     for (const BookmarkPtr &bookmark : list) {
-        //
-        // Check if the bookmark label is already in use
-        //
-        if (!bookmark->label().isEmpty() && findBookmarkByLabel(bookmark->label())) {
-            Smb4KNotification::bookmarkLabelInUse(bookmark);
-            bookmark->setLabel(bookmark->label() + QStringLiteral(" (1)"));
-        }
-
-        //
-        // Check if we have to add the bookmark
-        //
-        BookmarkPtr existingBookmark = findBookmarkByUrl(bookmark->url());
-
-        if (!existingBookmark) {
-            d->bookmarks << bookmark;
-            Q_EMIT bookmarkAdded(bookmark);
+        if (add(bookmark)) {
+            added = true;
         }
     }
 
-    //
-    // Save the bookmark list and emit the updated() signal
-    //
-    writeBookmarkList();
-    Q_EMIT updated();
+    if (added) {
+        write();
+        Q_EMIT updated();
+    }
 }
 
 void Smb4KBookmarkHandler::removeBookmark(const BookmarkPtr &bookmark)
 {
-    if (bookmark) {
-        for (int i = 0; i < d->bookmarks.size(); ++i) {
-            if ((!Smb4KSettings::useProfiles() || Smb4KSettings::activeProfile() == d->bookmarks.at(i)->profile())
-                && QString::compare(d->bookmarks.at(i)->url().toString(QUrl::RemoveUserInfo | QUrl::RemovePort),
-                                    bookmark->url().toString(QUrl::RemoveUserInfo | QUrl::RemovePort),
-                                    Qt::CaseInsensitive)
-                    == 0
-                && QString::compare(bookmark->categoryName(), d->bookmarks.at(i)->categoryName(), Qt::CaseInsensitive) == 0) {
-                BookmarkPtr bookmark = d->bookmarks.takeAt(i);
-                Q_EMIT bookmarkRemoved(bookmark);
-                bookmark.clear();
-                break;
-            }
-        }
-
-        // Write the list to the bookmarks file.
-        writeBookmarkList();
+    if (bookmark && remove(bookmark)) {
+        write();
         Q_EMIT updated();
     }
 }
 
 void Smb4KBookmarkHandler::removeCategory(const QString &name)
 {
+    if (!name.isEmpty() && remove(name)) {
+        write();
+        Q_EMIT updated();
+    }
+}
+
+BookmarkPtr Smb4KBookmarkHandler::findBookmarkByUrl(const QUrl &url)
+{
+    BookmarkPtr bookmark;
+    QList<BookmarkPtr> temporalBookmarkList = bookmarkList();
+
+    if (!url.isEmpty() && url.isValid() && !temporalBookmarkList.isEmpty()) {
+        for (const BookmarkPtr &b : std::as_const(temporalBookmarkList)) {
+            // NOTE: Since also user provided URLs can be bookmarked, we cannot use
+            // QUrl::matches() here, because it does not allow for case insensitive
+            // comparison.
+            if (QString::compare(url.toString(QUrl::RemoveUserInfo | QUrl::RemovePort),
+                                 b->url().toString(QUrl::RemoveUserInfo | QUrl::RemovePort),
+                                 Qt::CaseInsensitive)
+                == 0) {
+                bookmark = b;
+                break;
+            }
+        }
+    }
+
+    return bookmark;
+}
+
+BookmarkPtr Smb4KBookmarkHandler::findBookmarkByLabel(const QString &label)
+{
+    BookmarkPtr bookmark;
+    QList<BookmarkPtr> temporalBookmarkList = bookmarkList();
+
+    for (const BookmarkPtr &b : std::as_const(temporalBookmarkList)) {
+        if (b->label().toUpper() == label.toUpper()) {
+            bookmark = b;
+            break;
+        }
+    }
+
+    return bookmark;
+}
+
+QList<BookmarkPtr> Smb4KBookmarkHandler::bookmarkList() const
+{
+    QList<BookmarkPtr> bookmarks;
+
+    if (Smb4KSettings::useProfiles()) {
+        for (const BookmarkPtr &bookmark : std::as_const(d->bookmarks)) {
+            if (bookmark->profile() == Smb4KProfileManager::self()->activeProfile()) {
+                bookmarks << bookmark;
+            }
+        }
+    } else {
+        bookmarks = d->bookmarks;
+    }
+
+    return bookmarks;
+}
+
+QList<BookmarkPtr> Smb4KBookmarkHandler::bookmarkList(const QString &categoryName) const
+{
+    QList<BookmarkPtr> bookmarks;
+    QList<BookmarkPtr> temporalBookmarkList = bookmarkList();
+
+    for (const BookmarkPtr &bookmark : std::as_const(temporalBookmarkList)) {
+        if (categoryName == bookmark->categoryName()) {
+            bookmarks << bookmark;
+        }
+    }
+
+    return bookmarks;
+}
+
+QStringList Smb4KBookmarkHandler::categoryList() const
+{
+    QStringList categories;
+    QList<BookmarkPtr> temporalBookmarkList = bookmarkList();
+
+    for (const BookmarkPtr &bookmark : std::as_const(temporalBookmarkList)) {
+        if (!categories.contains(bookmark->categoryName())) {
+            categories << bookmark->categoryName();
+        }
+    }
+
+    return categories;
+}
+
+bool Smb4KBookmarkHandler::isBookmarked(const SharePtr &share)
+{
+    if (findBookmarkByUrl(share->url())) {
+        return true;
+    }
+
+    return false;
+}
+
+bool Smb4KBookmarkHandler::add(const BookmarkPtr &bookmark)
+{
+    bool addedBookmark = false;
+
+    if (findBookmarkByUrl(bookmark->url()).isNull()) {
+        if (bookmark->profile().isEmpty()) {
+            bookmark->setProfile(Smb4KProfileManager::self()->activeProfile());
+        }
+
+        if (!bookmark->label().isEmpty() && findBookmarkByLabel(bookmark->label())) {
+            Smb4KNotification::bookmarkLabelInUse(bookmark);
+            bookmark->setLabel(bookmark->label() + QStringLiteral(" (1)"));
+        }
+
+        d->bookmarks << bookmark;
+        addedBookmark = true;
+    } else {
+        Smb4KNotification::bookmarkExists(bookmark);
+    }
+
+    return addedBookmark;
+}
+
+bool Smb4KBookmarkHandler::remove(const BookmarkPtr &bookmark)
+{
+    bool removedBookmark = false;
     QMutableListIterator<BookmarkPtr> it(d->bookmarks);
 
     while (it.hasNext()) {
-        const BookmarkPtr &bookmark = it.next();
+        BookmarkPtr b = it.next();
 
-        if ((!Smb4KSettings::useProfiles() || Smb4KSettings::activeProfile() == bookmark->profile())
-            || QString::compare(bookmark->categoryName(), name, Qt::CaseInsensitive) == 0) {
-            Q_EMIT bookmarkRemoved(bookmark);
+        if ((!Smb4KSettings::useProfiles() || b->profile() == Smb4KProfileManager::self()->activeProfile())
+            && QString::compare(bookmark->url().toString(QUrl::RemoveUserInfo | QUrl::RemovePort),
+                                b->url().toString(QUrl::RemoveUserInfo | QUrl::RemovePort),
+                                Qt::CaseInsensitive)
+                == 0
+            && bookmark->categoryName() == b->categoryName()) {
             it.remove();
+            removedBookmark = true;
+            b.clear();
         }
     }
 
-    // Write the list to the bookmarks file.
-    writeBookmarkList();
-    Q_EMIT updated();
+    return removedBookmark;
 }
 
-void Smb4KBookmarkHandler::writeBookmarkList()
+bool Smb4KBookmarkHandler::remove(const QString &name)
 {
-    QFile xmlFile(dataLocation() + QDir::separator() + QStringLiteral("bookmarks.xml"));
+    bool removedCategory = false;
+    QMutableListIterator<BookmarkPtr> it(d->bookmarks);
 
-    if (!d->bookmarks.isEmpty()) {
-        if (xmlFile.open(QIODevice::WriteOnly | QIODevice::Text)) {
-            QXmlStreamWriter xmlWriter(&xmlFile);
-            xmlWriter.setAutoFormatting(true);
-            xmlWriter.writeStartDocument();
-            xmlWriter.writeStartElement(QStringLiteral("bookmarks"));
-            xmlWriter.writeAttribute(QStringLiteral("version"), QStringLiteral("3.1"));
+    while (it.hasNext()) {
+        BookmarkPtr b = it.next();
 
-            for (const BookmarkPtr &bookmark : qAsConst(d->bookmarks)) {
-                if (!bookmark->url().isValid()) {
-                    Smb4KNotification::invalidURLPassed();
-                    continue;
-                }
-
-                xmlWriter.writeStartElement(QStringLiteral("bookmark"));
-                xmlWriter.writeAttribute(QStringLiteral("profile"), bookmark->profile());
-                xmlWriter.writeAttribute(QStringLiteral("category"), bookmark->categoryName());
-
-                xmlWriter.writeTextElement(QStringLiteral("workgroup"), bookmark->workgroupName());
-                xmlWriter.writeTextElement(QStringLiteral("url"), bookmark->url().toString(QUrl::RemovePassword | QUrl::RemovePort));
-                xmlWriter.writeTextElement(QStringLiteral("ip"), bookmark->hostIpAddress());
-                xmlWriter.writeTextElement(QStringLiteral("label"), bookmark->label());
-
-                xmlWriter.writeEndElement();
-            }
-
-            xmlWriter.writeEndDocument();
-
-            xmlFile.close();
-        } else {
-            Smb4KNotification::openingFileFailed(xmlFile);
+        if ((!Smb4KSettings::useProfiles() || b->profile() == Smb4KProfileManager::self()->activeProfile()) && b->categoryName() == name) {
+            it.remove();
+            removedCategory = true;
+            b.clear();
         }
-    } else {
-        xmlFile.remove();
     }
+
+    return removedCategory;
 }
 
-void Smb4KBookmarkHandler::readBookmarkList()
+void Smb4KBookmarkHandler::read()
 {
-    //
-    // Clear the list of bookmarks
-    //
     while (!d->bookmarks.isEmpty()) {
         d->bookmarks.takeFirst().clear();
     }
 
-    //
-    // Locate the XML file and read the bookmarks
-    //
     QFile xmlFile(dataLocation() + QDir::separator() + QStringLiteral("bookmarks.xml"));
 
     if (xmlFile.open(QIODevice::ReadOnly | QIODevice::Text)) {
@@ -266,18 +303,9 @@ void Smb4KBookmarkHandler::readBookmarkList()
                     break;
                 } else {
                     if (xmlReader.name() == QStringLiteral("bookmark")) {
-                        QString profile = xmlReader.attributes().value(QStringLiteral("profile")).toString();
-
                         BookmarkPtr bookmark = BookmarkPtr(new Smb4KBookmark());
-                        bookmark->setProfile(profile);
-
-                        if (xmlReader.attributes().hasAttribute(QStringLiteral("group"))) {
-                            // For backward compatibility (since Smb4K 3.0.72)
-                            // TODO: Remove with Smb4K >> 3.1
-                            bookmark->setCategoryName(xmlReader.attributes().value(QStringLiteral("group")).toString());
-                        } else {
-                            bookmark->setCategoryName(xmlReader.attributes().value(QStringLiteral("category")).toString());
-                        }
+                        bookmark->setProfile(xmlReader.attributes().value(QStringLiteral("profile")).toString());
+                        bookmark->setCategoryName(xmlReader.attributes().value(QStringLiteral("category")).toString());
 
                         while (!(xmlReader.isEndElement() && xmlReader.name() == QStringLiteral("bookmark"))) {
                             xmlReader.readNext();
@@ -323,114 +351,46 @@ void Smb4KBookmarkHandler::readBookmarkList()
             Smb4KNotification::openingFileFailed(xmlFile);
         }
     }
-
-    Q_EMIT updated();
 }
 
-BookmarkPtr Smb4KBookmarkHandler::findBookmarkByUrl(const QUrl &url)
+void Smb4KBookmarkHandler::write()
 {
-    BookmarkPtr bookmark;
-    QList<BookmarkPtr> temporalBookmarkList = bookmarkList();
+    QFile xmlFile(dataLocation() + QDir::separator() + QStringLiteral("bookmarks.xml"));
 
-    if (!url.isEmpty() && url.isValid() && !temporalBookmarkList.isEmpty()) {
-        for (const BookmarkPtr &b : qAsConst(temporalBookmarkList)) {
-            // NOTE: Since also user provided URLs can be bookmarked, we cannot use
-            // QUrl::matches() here, because it does not allow for case insensitive
-            // comparison.
-            if (QString::compare(url.toString(QUrl::RemoveUserInfo | QUrl::RemovePort),
-                                 b->url().toString(QUrl::RemoveUserInfo | QUrl::RemovePort),
-                                 Qt::CaseInsensitive)
-                == 0) {
-                bookmark = b;
-                break;
+    if (!d->bookmarks.isEmpty()) {
+        if (xmlFile.open(QIODevice::WriteOnly | QIODevice::Text)) {
+            QXmlStreamWriter xmlWriter(&xmlFile);
+            xmlWriter.setAutoFormatting(true);
+            xmlWriter.writeStartDocument();
+            xmlWriter.writeStartElement(QStringLiteral("bookmarks"));
+            xmlWriter.writeAttribute(QStringLiteral("version"), QStringLiteral("3.1"));
+
+            for (const BookmarkPtr &bookmark : std::as_const(d->bookmarks)) {
+                if (!bookmark->url().isValid()) {
+                    Smb4KNotification::invalidURLPassed();
+                    continue;
+                }
+
+                xmlWriter.writeStartElement(QStringLiteral("bookmark"));
+                xmlWriter.writeAttribute(QStringLiteral("profile"), bookmark->profile());
+                xmlWriter.writeAttribute(QStringLiteral("category"), bookmark->categoryName());
+
+                xmlWriter.writeTextElement(QStringLiteral("workgroup"), bookmark->workgroupName());
+                xmlWriter.writeTextElement(QStringLiteral("url"), bookmark->url().toString(QUrl::RemovePassword | QUrl::RemovePort));
+                xmlWriter.writeTextElement(QStringLiteral("ip"), bookmark->hostIpAddress());
+                xmlWriter.writeTextElement(QStringLiteral("label"), bookmark->label());
+
+                xmlWriter.writeEndElement();
             }
-        }
-    }
 
-    return bookmark;
-}
+            xmlWriter.writeEndDocument();
 
-BookmarkPtr Smb4KBookmarkHandler::findBookmarkByLabel(const QString &label)
-{
-    BookmarkPtr bookmark;
-    QList<BookmarkPtr> temporalBookmarkList = bookmarkList();
-
-    for (const BookmarkPtr &b : qAsConst(temporalBookmarkList)) {
-        if (QString::compare(b->label().toUpper(), label.toUpper()) == 0) {
-            bookmark = b;
-            break;
-        }
-    }
-
-    return bookmark;
-}
-
-QList<BookmarkPtr> Smb4KBookmarkHandler::bookmarkList() const
-{
-    QList<BookmarkPtr> bookmarks;
-
-    update();
-
-    if (Smb4KSettings::useProfiles()) {
-        for (const BookmarkPtr &bookmark : qAsConst(d->bookmarks)) {
-            if (bookmark->profile() == Smb4KSettings::activeProfile()) {
-                bookmarks << bookmark;
-            }
+            xmlFile.close();
+        } else {
+            Smb4KNotification::openingFileFailed(xmlFile);
         }
     } else {
-        bookmarks = d->bookmarks;
-    }
-
-    return bookmarks;
-}
-
-QList<BookmarkPtr> Smb4KBookmarkHandler::bookmarkList(const QString &categoryName) const
-{
-    QList<BookmarkPtr> bookmarks;
-    QList<BookmarkPtr> temporalBookmarkList = bookmarkList();
-
-    for (const BookmarkPtr &bookmark : qAsConst(temporalBookmarkList)) {
-        if (categoryName == bookmark->categoryName()) {
-            bookmarks << bookmark;
-        }
-    }
-
-    return bookmarks;
-}
-
-QStringList Smb4KBookmarkHandler::categoryList() const
-{
-    QStringList categories;
-    QList<BookmarkPtr> temporalBookmarkList = bookmarkList();
-
-    for (const BookmarkPtr &bookmark : qAsConst(temporalBookmarkList)) {
-        if (!categories.contains(bookmark->categoryName())) {
-            categories << bookmark->categoryName();
-        }
-    }
-
-    return categories;
-}
-
-bool Smb4KBookmarkHandler::isBookmarked(const SharePtr &share)
-{
-    if (findBookmarkByUrl(share->url())) {
-        return true;
-    }
-
-    return false;
-}
-
-void Smb4KBookmarkHandler::update() const
-{
-    for (const BookmarkPtr &bookmark : qAsConst(d->bookmarks)) {
-        HostPtr host = findHost(bookmark->hostName(), bookmark->workgroupName());
-
-        if (host) {
-            if (host->hasIpAddress() && bookmark->hostIpAddress() != host->ipAddress()) {
-                bookmark->setHostIpAddress(host->ipAddress());
-            }
-        }
+        xmlFile.remove();
     }
 }
 
@@ -446,19 +406,25 @@ void Smb4KBookmarkHandler::slotProfileRemoved(const QString &name)
         }
     }
 
-    // Write the new list to the file.
-    writeBookmarkList();
+    write();
+    Q_EMIT updated();
 }
 
 void Smb4KBookmarkHandler::slotProfileMigrated(const QString &oldName, const QString &newName)
 {
-    for (const BookmarkPtr &bookmark : qAsConst(d->bookmarks)) {
+    for (const BookmarkPtr &bookmark : std::as_const(d->bookmarks)) {
         if (oldName == bookmark->profile()) {
             bookmark->setProfile(newName);
             continue;
         }
     }
 
-    // Write the new list to the file.
-    writeBookmarkList();
+    write();
+    Q_EMIT updated();
+}
+
+void Smb4KBookmarkHandler::slotActiveProfileChanged(const QString &name)
+{
+    Q_UNUSED(name);
+    Q_EMIT updated();
 }
