@@ -1,7 +1,7 @@
 /*
     Manage custom settings
 
-    SPDX-FileCopyrightText: 2011-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2011-2024 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -64,6 +64,7 @@ Smb4KCustomSettingsManager::Smb4KCustomSettingsManager(QObject *parent)
 
     connect(Smb4KProfileManager::self(), &Smb4KProfileManager::profileRemoved, this, &Smb4KCustomSettingsManager::slotProfileRemoved);
     connect(Smb4KProfileManager::self(), &Smb4KProfileManager::profileMigrated, this, &Smb4KCustomSettingsManager::slotProfileMigrated);
+    connect(Smb4KProfileManager::self(), &Smb4KProfileManager::activeProfileChanged, this, &Smb4KCustomSettingsManager::slotActiveProfileChanged);
 }
 
 Smb4KCustomSettingsManager::~Smb4KCustomSettingsManager()
@@ -78,12 +79,13 @@ Smb4KCustomSettingsManager *Smb4KCustomSettingsManager::self()
 void Smb4KCustomSettingsManager::addRemount(const SharePtr &share, bool always)
 {
     if (share) {
+        bool addedSettings = false;
         CustomSettingsPtr settings = findCustomSettings(share, true);
 
         if (!settings) {
             settings = CustomSettingsPtr(new Smb4KCustomSettings(share.data()));
             // add() takes care of the profile, we do not need to set it here.
-            add(settings);
+            addedSettings = add(settings);
         }
 
         // If the options are already in the list, check if the share is
@@ -93,8 +95,10 @@ void Smb4KCustomSettingsManager::addRemount(const SharePtr &share, bool always)
             settings->setRemount(always ? Smb4KCustomSettings::RemountAlways : Smb4KCustomSettings::RemountOnce);
         }
 
-        write();
-        Q_EMIT updated();
+        if (addedSettings) {
+            write();
+            Q_EMIT updated();
+        }
     }
 }
 
@@ -124,7 +128,7 @@ void Smb4KCustomSettingsManager::clearRemounts(bool force)
 {
     QList<CustomSettingsPtr> settingsList = customSettings(false);
 
-    for (const CustomSettingsPtr &settings : qAsConst(settingsList)) {
+    for (const CustomSettingsPtr &settings : std::as_const(settingsList)) {
         if (settings->type() == Share) {
             if (settings->remount() == Smb4KCustomSettings::RemountOnce) {
                 settings->setRemount(Smb4KCustomSettings::UndefinedRemount);
@@ -147,7 +151,7 @@ QList<CustomSettingsPtr> Smb4KCustomSettingsManager::sharesToRemount()
     QList<CustomSettingsPtr> settingsList = customSettings(false);
     QList<CustomSettingsPtr> remountsList;
 
-    for (const CustomSettingsPtr &settings : qAsConst(settingsList)) {
+    for (const CustomSettingsPtr &settings : std::as_const(settingsList)) {
         if (settings->remount() != Smb4KCustomSettings::UndefinedRemount) {
             remountsList << settings;
         }
@@ -179,7 +183,7 @@ CustomSettingsPtr Smb4KCustomSettingsManager::findCustomSettings(const QUrl &url
     if (url.isValid() && url.scheme() == QStringLiteral("smb")) {
         QList<CustomSettingsPtr> settingsList = customSettings(false);
 
-        for (const CustomSettingsPtr &cs : qAsConst(settingsList)) {
+        for (const CustomSettingsPtr &cs : std::as_const(settingsList)) {
             if (cs->url().toString(QUrl::RemoveUserInfo | QUrl::RemovePort | QUrl::StripTrailingSlash)
                 == url.toString(QUrl::RemoveUserInfo | QUrl::RemovePort | QUrl::StripTrailingSlash)) {
                 settings = cs;
@@ -195,8 +199,8 @@ QList<CustomSettingsPtr> Smb4KCustomSettingsManager::customSettings(bool without
 {
     QList<CustomSettingsPtr> settingsList;
 
-    for (const CustomSettingsPtr &settings : qAsConst(d->customSettings)) {
-        if (Smb4KSettings::useProfiles() && settings->profile() != Smb4KProfileManager::self()->activeProfile()) {
+    for (const CustomSettingsPtr &settings : std::as_const(d->customSettings)) {
+        if (Smb4KSettings::useProfiles() && (settings->profile() != Smb4KProfileManager::self()->activeProfile())) {
             continue;
         }
 
@@ -210,8 +214,7 @@ QList<CustomSettingsPtr> Smb4KCustomSettingsManager::customSettings(bool without
 
 void Smb4KCustomSettingsManager::addCustomSettings(const CustomSettingsPtr &settings)
 {
-    if (settings) {
-        add(settings);
+    if (settings && add(settings)) {
         write();
         Q_EMIT updated();
     }
@@ -219,8 +222,7 @@ void Smb4KCustomSettingsManager::addCustomSettings(const CustomSettingsPtr &sett
 
 void Smb4KCustomSettingsManager::removeCustomSettings(const CustomSettingsPtr &settings)
 {
-    if (settings) {
-        remove(settings);
+    if (settings && remove(settings)) {
         write();
         Q_EMIT updated();
     }
@@ -231,7 +233,7 @@ QList<CustomSettingsPtr> Smb4KCustomSettingsManager::wakeOnLanEntries() const
     QList<CustomSettingsPtr> wakeOnLanList;
     QList<CustomSettingsPtr> settingsList = customSettings();
 
-    for (const CustomSettingsPtr &settings : qAsConst(settingsList)) {
+    for (const CustomSettingsPtr &settings : std::as_const(settingsList)) {
         if (!settings->macAddress().isEmpty() && (settings->wakeOnLanSendBeforeNetworkScan() || settings->wakeOnLanSendBeforeMount())) {
             wakeOnLanList << settings;
         }
@@ -243,58 +245,81 @@ QList<CustomSettingsPtr> Smb4KCustomSettingsManager::wakeOnLanEntries() const
 void Smb4KCustomSettingsManager::saveCustomSettings(const QList<CustomSettingsPtr> &settingsList)
 {
     QMutableListIterator<CustomSettingsPtr> it(d->customSettings);
+    bool addedSettings = false;
 
+    // NOTE: Do not use Smb4KCustomSettingsManager::remove() here to avoid crashes.
     while (it.hasNext()) {
         CustomSettingsPtr settings = it.next();
-        remove(settings);
+
+        if (!Smb4KSettings::useProfiles() || (settings->profile() == Smb4KProfileManager::self()->activeProfile())) {
+            it.remove();
+            settings.clear();
+        }
     }
 
     for (const CustomSettingsPtr &settings : settingsList) {
-        add(settings);
+        if (add(settings)) {
+            addedSettings = true;
+        }
     }
 
-    write();
-    Q_EMIT updated();
+    if (addedSettings) {
+        write();
+        Q_EMIT updated();
+    }
 }
 
-void Smb4KCustomSettingsManager::add(const CustomSettingsPtr &settings)
+bool Smb4KCustomSettingsManager::add(const CustomSettingsPtr &settings)
 {
-    CustomSettingsPtr knownSettings = findCustomSettings(settings->url());
+    bool addedSettings = false;
 
-    if (knownSettings) {
-        knownSettings->update(settings.data());
-    } else {
-        if (settings->profile().isEmpty()) {
-            settings->setProfile(Smb4KProfileManager::self()->activeProfile());
+    if (settings->hasCustomSettings()) {
+        CustomSettingsPtr knownSettings = findCustomSettings(settings->url());
+
+        if (knownSettings) {
+            knownSettings->update(settings.data());
+        } else {
+            if (settings->profile().isEmpty()) {
+                settings->setProfile(Smb4KProfileManager::self()->activeProfile());
+            }
+            d->customSettings << settings;
         }
 
-        d->customSettings << settings;
-    }
+        // Propagate the settings to the host's shares if the type is 'Host'
+        if (settings->type() == Host) {
+            QList<CustomSettingsPtr> customSettingsList = customSettings(true);
 
-    // Propagate the settings to the host's shares if the type is 'Host'
-    if (settings->type() == Host) {
-        QList<CustomSettingsPtr> customSettingsList = customSettings(true);
-
-        for (const CustomSettingsPtr &cs : qAsConst(customSettingsList)) {
-            // Since only the URL is important, do not check for the workgroup.
-            // Also, if the workgroup is a DNS-SD domain, it is most likely not
-            // a valid SMB workgroup or domain.
-            if (cs->type() == Share && cs->hostName() == settings->hostName()) {
-                cs->update(settings.data());
+            for (const CustomSettingsPtr &cs : std::as_const(customSettingsList)) {
+                // Since only the URL is important, do not check for the workgroup.
+                // Also, if the workgroup is a DNS-SD domain, it is most likely not
+                // a valid SMB workgroup or domain.
+                if (cs->type() == Share && cs->hostName() == settings->hostName()) {
+                    cs->update(settings.data());
+                }
             }
         }
+
+        addedSettings = true;
     }
+
+    return addedSettings;
 }
 
-void Smb4KCustomSettingsManager::remove(const CustomSettingsPtr &settings)
+bool Smb4KCustomSettingsManager::remove(const CustomSettingsPtr &settings)
 {
+    bool removedSettings = false;
+
+    // FIXME: Use while loop here
     for (int i = 0; i < d->customSettings.size(); i++) {
         if ((!Smb4KSettings::useProfiles() || Smb4KProfileManager::self()->activeProfile() == d->customSettings.at(i)->profile())
             && d->customSettings.at(i)->url().matches(settings->url(), QUrl::RemoveUserInfo | QUrl::RemovePort | QUrl::StripTrailingSlash)) {
             d->customSettings.takeAt(i).clear();
+            removedSettings = true;
             break;
         }
     }
+
+    return removedSettings;
 }
 
 void Smb4KCustomSettingsManager::read()
@@ -370,7 +395,7 @@ void Smb4KCustomSettingsManager::read()
                                                 QRegularExpression expression(QStringLiteral("..\\:..\\:..\\:..\\:..\\:.."));
 
                                                 if (expression.match(macAddress).hasMatch()) {
-                                                    settings->setMACAddress(macAddress);
+                                                    settings->setMacAddress(macAddress);
                                                 }
                                             } else if (xmlReader.name() == QStringLiteral("wol_send_before_first_scan")) {
                                                 bool ok = false;
@@ -575,7 +600,7 @@ void Smb4KCustomSettingsManager::write()
         xmlWriter.writeStartElement(QStringLiteral("custom_options"));
         xmlWriter.writeAttribute(QStringLiteral("version"), QStringLiteral("3.0"));
 
-        for (const CustomSettingsPtr &settings : qAsConst(d->customSettings)) {
+        for (const CustomSettingsPtr &settings : std::as_const(d->customSettings)) {
             if (settings->hasCustomSettings()) {
                 xmlWriter.writeStartElement(QStringLiteral("options"));
                 xmlWriter.writeAttribute(QStringLiteral("type"), settings->type() == Host ? QStringLiteral("host") : QStringLiteral("share"));
@@ -623,6 +648,7 @@ void Smb4KCustomSettingsManager::slotProfileRemoved(const QString &name)
 
         if (name == settings->profile()) {
             it.remove();
+            settings.clear();
         }
     }
 
@@ -632,7 +658,7 @@ void Smb4KCustomSettingsManager::slotProfileRemoved(const QString &name)
 
 void Smb4KCustomSettingsManager::slotProfileMigrated(const QString &oldName, const QString &newName)
 {
-    for (const CustomSettingsPtr &settings : qAsConst(d->customSettings)) {
+    for (const CustomSettingsPtr &settings : std::as_const(d->customSettings)) {
         if (oldName == settings->profile()) {
             settings->setProfile(newName);
         }
@@ -641,3 +667,9 @@ void Smb4KCustomSettingsManager::slotProfileMigrated(const QString &oldName, con
     write();
     Q_EMIT updated();
 }
+
+void Smb4KCustomSettingsManager::slotActiveProfileChanged(const QString &name)
+{
+    Q_UNUSED(name);
+    Q_EMIT updated();
+}
