@@ -1,15 +1,15 @@
 /*
     The core class that mounts the shares.
 
-    SPDX-FileCopyrightText: 2003-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2003-2024 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 // Application specific includes
 #include "smb4kmounter.h"
-#include "smb4kauthinfo.h"
 #include "smb4kbookmark.h"
 #include "smb4kbookmarkhandler.h"
+#include "smb4kcredentialsmanager.h"
 #include "smb4kcustomsettings.h"
 #include "smb4kcustomsettingsmanager.h"
 #include "smb4khardwareinterface.h"
@@ -18,7 +18,6 @@
 #include "smb4kprofilemanager.h"
 #include "smb4ksettings.h"
 #include "smb4kshare.h"
-#include "smb4kwalletmanager.h"
 #include "smb4kworkgroup.h"
 
 #if defined(Q_OS_LINUX)
@@ -98,7 +97,7 @@ Smb4KMounter::Smb4KMounter(QObject *parent)
     //
     connect(Smb4KProfileManager::self(), &Smb4KProfileManager::aboutToChangeProfile, this, &Smb4KMounter::slotAboutToChangeProfile);
     connect(Smb4KProfileManager::self(), &Smb4KProfileManager::activeProfileChanged, this, &Smb4KMounter::slotActiveProfileChanged);
-    connect(Smb4KWalletManager::self(), &Smb4KWalletManager::credentialsUpdated, this, &Smb4KMounter::slotCredentialsUpdated);
+    connect(Smb4KCredentialsManager::self(), &Smb4KCredentialsManager::credentialsUpdated, this, &Smb4KMounter::slotCredentialsUpdated);
     connect(Smb4KMountSettings::self(), &Smb4KMountSettings::configChanged, this, &Smb4KMounter::slotConfigChanged);
 
     connect(Smb4KHardwareInterface::self(), &Smb4KHardwareInterface::onlineStateChanged, this, &Smb4KMounter::slotOnlineStateChanged);
@@ -151,7 +150,7 @@ void Smb4KMounter::triggerRemounts(bool fillList)
         //
         // Process the list and honor the settings the user chose
         //
-        for (const CustomSettingsPtr &option : qAsConst(options)) {
+        for (const CustomSettingsPtr &option : std::as_const(options)) {
             //
             // Skip one time remount shares, if needed
             //
@@ -165,7 +164,7 @@ void Smb4KMounter::triggerRemounts(bool fillList)
             QList<SharePtr> mountedShares = findShareByUrl(option->url());
             bool remountShare = true;
 
-            for (const SharePtr &share : qAsConst(mountedShares)) {
+            for (const SharePtr &share : std::as_const(mountedShares)) {
                 if (!share->isForeign()) {
                     remountShare = false;
                     break;
@@ -178,7 +177,7 @@ void Smb4KMounter::triggerRemounts(bool fillList)
             if (remountShare) {
                 bool insertShare = true;
 
-                for (const SharePtr &share : qAsConst(d->remounts)) {
+                for (const SharePtr &share : std::as_const(d->remounts)) {
                     if (QString::compare(share->url().toString(QUrl::RemoveUserInfo | QUrl::RemovePort),
                                          option->url().toString(QUrl::RemoveUserInfo | QUrl::RemovePort))
                         == 0) {
@@ -226,7 +225,7 @@ void Smb4KMounter::import(bool checkInaccessible)
     //
     KMountPoint::List mountPoints = KMountPoint::currentMountPoints(KMountPoint::BasicInfoNeeded | KMountPoint::NeedMountOptions);
 
-    for (const QExplicitlySharedDataPointer<KMountPoint> &mountPoint : qAsConst(mountPoints)) {
+    for (const QExplicitlySharedDataPointer<KMountPoint> &mountPoint : std::as_const(mountPoints)) {
         if (!mountPoint->isOnNetwork()) {
             continue;
         }
@@ -251,7 +250,7 @@ void Smb4KMounter::import(bool checkInaccessible)
 
             QStringList mountOptions = mountPoint->mountOptions();
 
-            for (const QString &option : qAsConst(mountOptions)) {
+            for (const QString &option : std::as_const(mountOptions)) {
                 if (option.startsWith(QStringLiteral("domain=")) || option.startsWith(QStringLiteral("workgroup="))) {
                     share->setWorkgroupName(option.section(QStringLiteral("="), 1, 1).trimmed());
                 } else if (option.startsWith(QStringLiteral("addr="))) {
@@ -389,7 +388,6 @@ void Smb4KMounter::import(bool checkInaccessible)
     }
 
     if (changedMountedSharesList) {
-        qDebug() << "Changed list of mounted shares!";
         Q_EMIT mountedSharesListChanged();
     }
 }
@@ -420,7 +418,7 @@ void Smb4KMounter::mountShare(const SharePtr &share)
         QList<SharePtr> mountedShares = findShareByUrl(url);
         bool isMounted = false;
 
-        for (const SharePtr &s : qAsConst(mountedShares)) {
+        for (const SharePtr &s : std::as_const(mountedShares)) {
             if (!s->isForeign()) {
                 isMounted = true;
                 break;
@@ -537,7 +535,7 @@ void Smb4KMounter::mountShare(const SharePtr &share)
         //
         // Get the authentication information
         //
-        Smb4KWalletManager::self()->readLoginCredentials(share);
+        Smb4KCredentialsManager::self()->readLoginCredentials(share);
 
         //
         // Mount arguments
@@ -859,8 +857,10 @@ void Smb4KMounter::saveSharesForRemount()
     }
 }
 
-void Smb4KMounter::timerEvent(QTimerEvent *)
+void Smb4KMounter::timerEvent(QTimerEvent *event)
 {
+    Q_UNUSED(event);
+
     if (!isRunning() && Smb4KHardwareInterface::self()->isOnline()) {
         //
         // Try to remount shares
@@ -1724,12 +1724,12 @@ void Smb4KMounter::slotAboutToQuit()
     QStringList hostDirs = dir.entryList(QDir::Dirs | QDir::NoDotAndDotDot, QDir::NoSort);
     QStringList mountpoints;
 
-    for (const QString &hostDir : qAsConst(hostDirs)) {
+    for (const QString &hostDir : std::as_const(hostDirs)) {
         dir.cd(hostDir);
 
         QStringList shareDirs = dir.entryList(QDir::Dirs | QDir::NoDotAndDotDot, QDir::NoSort);
 
-        for (const QString &shareDir : qAsConst(shareDirs)) {
+        for (const QString &shareDir : std::as_const(shareDirs)) {
             dir.cd(shareDir);
             mountpoints << dir.absolutePath();
             dir.cdUp();
@@ -1739,12 +1739,12 @@ void Smb4KMounter::slotAboutToQuit()
     }
 
     // Remove those mountpoints where a share is actually mounted.
-    for (const QExplicitlySharedDataPointer<KMountPoint> &mountPoint : qAsConst(mountPoints)) {
+    for (const QExplicitlySharedDataPointer<KMountPoint> &mountPoint : std::as_const(mountPoints)) {
         mountpoints.removeOne(mountPoint->mountPoint());
     }
 
     // Remove the empty mountpoints.
-    for (const QString &mp : qAsConst(mountpoints)) {
+    for (const QString &mp : std::as_const(mountpoints)) {
         dir.cd(mp);
         dir.rmdir(dir.canonicalPath());
 
@@ -1830,14 +1830,10 @@ void Smb4KMounter::slotConfigChanged()
 void Smb4KMounter::slotCredentialsUpdated(const QUrl &url)
 {
     if (!url.isEmpty() && !d->retries.isEmpty()) {
-        QMutableListIterator<SharePtr> it(d->retries);
+        for (int i = 0; i < d->retries.size(); i++) {
+            QUrl parentUrl = d->retries[i]->url().resolved(QUrl(QStringLiteral(".."))).adjusted(QUrl::StripTrailingSlash);
 
-        while (it.hasNext()) {
-            SharePtr share = it.next();
-
-            QUrl parentUrl = share->url().resolved(QUrl(QStringLiteral(".."))).adjusted(QUrl::StripTrailingSlash);
-
-            if (QString::compare(share->url().toString(QUrl::RemoveUserInfo | QUrl::RemovePort),
+            if (QString::compare(d->retries[i]->url().toString(QUrl::RemoveUserInfo | QUrl::RemovePort),
                                  url.toString(QUrl::RemoveUserInfo | QUrl::RemovePort),
                                  Qt::CaseInsensitive)
                     == 0
@@ -1845,12 +1841,11 @@ void Smb4KMounter::slotCredentialsUpdated(const QUrl &url)
                                     url.toString(QUrl::RemoveUserInfo | QUrl::RemovePort),
                                     Qt::CaseInsensitive)
                     == 0) {
+                SharePtr share = d->retries.takeAt(i);
                 share->setUserName(url.userName());
                 share->setPassword(url.password());
 
                 mountShare(share);
-
-                it.remove();
             }
         }
     }
