@@ -70,13 +70,9 @@ void Smb4KNotification::shareMounted(const SharePtr &share)
             job->start();
         };
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         auto *openAction = notification->addAction(i18nc("Open the contents of the share with the file manager", "Open"));
         QObject::connect(openAction, &KNotificationAction::activated, open);
-#else
-        notification->setActions(QStringList(i18nc("Open the contents of the share with the file manager", "Open")));
-        QObject::connect(notification, &KNotification::action1Activated, open);
-#endif
+
         QObject::connect(notification, &KNotification::closed, &loop, &QEventLoop::quit);
 
         notification->sendEvent();
@@ -140,38 +136,25 @@ void Smb4KNotification::sharesUnmounted(int number)
     notification->sendEvent();
 }
 
-//
-// Warnings
-//
-
-void Smb4KNotification::openingWalletFailed(const QString &name)
+void Smb4KNotification::migratingLoginCredentials()
 {
-    KNotification *notification = new KNotification(QStringLiteral("openingWalletFailed"), KNotification::CloseOnTimeout);
-
-    if (!p->componentName.isEmpty()) {
-        notification->setComponentName(p->componentName);
-    }
-
-    notification->setText(i18n("<p>Opening the wallet <b>%1</b> failed.</p>", name));
-    notification->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("dialog-warning"), KIconLoader::NoGroup, 0, KIconLoader::DefaultState));
-    notification->sendEvent();
-}
-
-void Smb4KNotification::credentialsNotAccessible()
-{
-    KNotification *notification = new KNotification(QStringLiteral("credentialsNotAccessible"), KNotification::CloseOnTimeout);
+    KNotification *notification = new KNotification(QStringLiteral("migratingCredentials"), KNotification::CloseOnTimeout);
 
     if (!p->componentName.isEmpty()) {
         notification->setComponentName(p->componentName);
     }
 
     notification->setText(
-        i18n("<p>The credentials stored in the wallet could not be accessed. "
-             "There is either no wallet available or it could not be opened.</p>"));
-    notification->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("dialog-warning"), KIconLoader::NoGroup, 0, KIconLoader::DefaultState));
+        i18n("The way Smb4K stores the login credentials has changed. They will now be migrated. "
+             "This change is incompatible with earlier versions of Smb4K."));
+    notification->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("dialog-information"), KIconLoader::NoGroup, 0, KIconLoader::DefaultState));
     notification->sendEvent();
 }
 
+//
+// Warnings
+//
+
 void Smb4KNotification::mimetypeNotSupported(const QString &mimetype)
 {
     KNotification *notification = new KNotification(QStringLiteral("mimetypeNotSupported"), KNotification::CloseOnTimeout);
@@ -568,3 +551,16 @@ void Smb4KNotification::zeroconfError(const QString &errorMessage)
     notification->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("dialog-error"), KIconLoader::NoGroup, 0, KIconLoader::DefaultState));
     notification->sendEvent();
 }
+
+void Smb4KNotification::keychainError(const QString &errorMessage)
+{
+    KNotification *notification = new KNotification(QStringLiteral("keychainError"), KNotification::CloseOnTimeout);
+
+    if (!p->componentName.isEmpty()) {
+        notification->setComponentName(p->componentName);
+    }
+
+    notification->setText(i18n("<p>An error occurred while reading the login credentials from the secure storage:\n<tt>%1</tt></p>", errorMessage));
+    notification->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("dialog-error"), KIconLoader::NoGroup, 0, KIconLoader::DefaultState));
+    notification->sendEvent();
+}
