@@ -1,7 +1,7 @@
 /*
     This class manages the profiles that were defined by the user.
 
-    SPDX-FileCopyrightText: 2014-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2014-2024 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -43,7 +43,7 @@ Smb4KProfileManager::Smb4KProfileManager(QObject *parent)
         d->activeProfile.clear();
     }
 
-    connect(Smb4KSettings::self(), SIGNAL(configChanged()), this, SLOT(slotConfigChanged()));
+    connect(Smb4KSettings::self(), &Smb4KSettings::configChanged, this, &Smb4KProfileManager::slotConfigChanged);
 }
 
 Smb4KProfileManager::~Smb4KProfileManager()
@@ -146,7 +146,6 @@ void Smb4KProfileManager::removeProfile(const QString &name)
 
 void Smb4KProfileManager::slotConfigChanged()
 {
-    // FIXME: Do we need to emit the signals here?
     if (d->useProfiles != Smb4KSettings::useProfiles()) {
         d->useProfiles = Smb4KSettings::useProfiles();
         Q_EMIT profileUsageChanged(d->useProfiles);
@@ -157,9 +156,13 @@ void Smb4KProfileManager::slotConfigChanged()
         Q_EMIT profilesListChanged(d->profiles);
     }
 
-    if (!Smb4KSettings::activeProfile().isEmpty() && d->profiles.contains(Smb4KSettings::activeProfile())) {
-        setActiveProfile(Smb4KSettings::activeProfile());
+    if (d->useProfiles) {
+        if (!Smb4KSettings::activeProfile().isEmpty() && d->profiles.contains(Smb4KSettings::activeProfile())) {
+            setActiveProfile(Smb4KSettings::activeProfile());
+        } else {
+            setActiveProfile(d->profiles.first());
+        }
     } else {
-        setActiveProfile(d->profiles.first());
+        setActiveProfile(QString());
     }
 }
