@@ -1,7 +1,7 @@
 /*
     The configuration dialog of Smb4K
 
-    SPDX-FileCopyrightText: 2004-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2004-2024 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -51,6 +51,12 @@ public:
      */
     ~Smb4KConfigDialog();
 
+protected:
+    /**
+     * Reimplemented from KConfigDialog
+     */
+    bool hasChanged() override;
+
 protected Q_SLOTS:
     /**
      * Reimplemented from KConfigDialog. Used to do things that
@@ -58,20 +64,21 @@ protected Q_SLOTS:
      */
     void updateSettings() override;
 
-    /**
-     * Enable/disable the "Apply" button if settings that are not managed by
-     * KConfig XT have changed.
-     */
-    void slotEnableApplyButton();
-
     /**
      * This slot is used to check the settings of the different pages.
      *
-     * @param current     the current dialog page
-     * @param before      the previous dialog page
+     * @param current           the current dialog page
+     * @param before            the previous dialog page
      */
     void slotCheckPage(KPageWidgetItem *current, KPageWidgetItem *before);
 
+    /**
+     * This slot is called when the active profile changed.
+     *
+     * @param activeProfile     the name of the active profile
+     */
+    void slotActiveProfileChanged(const QString &activeProfile);
+
 private:
     /**
      * Set up the config dialog.
