@@ -1,7 +1,7 @@
 /*
  *  Editor widget for the custom settings
  *
- *  SPDX-FileCopyrightText: 2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+ *  SPDX-FileCopyrightText: 2023-2024 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
@@ -26,10 +26,11 @@ using namespace Smb4KGlobal;
 Smb4KCustomSettingsEditorWidget::Smb4KCustomSettingsEditorWidget(QWidget *parent)
     : QTabWidget(parent)
 {
-    // FIXME: Implement mount point!?
+    m_hasDefaultCustomSettings = true;
 
+    // FIXME: Implement mount point!?
     // FIXME: Honor disabled widgets and unchecked check boxes!?
-    m_haveCustomSettings = false;
+
     setupView();
 }
 
@@ -80,7 +81,7 @@ void Smb4KCustomSettingsEditorWidget::setupView()
 
     QList<KCoreConfigSkeleton::ItemEnum::Choice> writeAccessChoices = Smb4KMountSettings::self()->writeAccessItem()->choices();
 
-    for (const KCoreConfigSkeleton::ItemEnum::Choice &wa : qAsConst(writeAccessChoices)) {
+    for (const KCoreConfigSkeleton::ItemEnum::Choice &wa : std::as_const(writeAccessChoices)) {
         m_writeAccess->addItem(wa.label);
     }
 
@@ -104,7 +105,7 @@ void Smb4KCustomSettingsEditorWidget::setupView()
 
     QList<KUser> allUsers = KUser::allUsers();
 
-    for (const KUser &user : qAsConst(allUsers)) {
+    for (const KUser &user : std::as_const(allUsers)) {
         m_userId->addItem(user.loginName() + QStringLiteral(" (") + user.userId().toString() + QStringLiteral(")"), user.userId().toString());
     }
 
@@ -116,7 +117,7 @@ void Smb4KCustomSettingsEditorWidget::setupView()
 
     QList<KUserGroup> allGroups = KUserGroup::allGroups();
 
-    for (const KUserGroup &group : qAsConst(allGroups)) {
+    for (const KUserGroup &group : std::as_const(allGroups)) {
         m_groupId->addItem(group.name() + QStringLiteral(" (") + group.groupId().toString() + QStringLiteral(")"), group.groupId().toString());
     }
 
@@ -251,12 +252,12 @@ void Smb4KCustomSettingsEditorWidget::setupView()
     QWidget *tab5 = new QWidget(this);
     QGridLayout *tab5Layout = new QGridLayout(tab5);
 
+    tab5->setEnabled(Smb4KSettings::enableWakeOnLAN());
+
     m_macAddressLabel = new QLabel(i18n("MAC Address:"), tab5);
-    m_macAddressLabel->setEnabled(false);
     m_macAddress = new KLineEdit(tab5);
     m_macAddress->setClearButtonEnabled(true);
     m_macAddress->setInputMask(QStringLiteral("HH:HH:HH:HH:HH:HH;_")); // MAC address, see QLineEdit doc
-    m_macAddress->setEnabled(false);
     m_macAddressLabel->setBuddy(m_macAddress);
 
     connect(m_macAddress, &KLineEdit::textChanged, this, &Smb4KCustomSettingsEditorWidget::slotMacAddressChanged);
@@ -275,7 +276,7 @@ void Smb4KCustomSettingsEditorWidget::setupView()
     tab5Layout->addWidget(m_sendPacketBeforeMount, 2, 0, 1, 2);
     tab5Layout->setRowStretch(3, 100);
 
-    addTab(tab5, i18n("Wake-On-LAN Settings"));
+    m_wakeOnLanTabIndex = addTab(tab5, i18n("Wake-On-LAN Settings"));
 }
 #elif defined(Q_OS_FREEBSD) || defined(Q_OS_NETBSD)
 void Smb4KCustomSettingsEditorWidget::setupView()
@@ -320,7 +321,7 @@ void Smb4KCustomSettingsEditorWidget::setupView()
 
     QList<KUser> allUsers = KUser::allUsers();
 
-    for (const KUser &user : qAsConst(allUsers)) {
+    for (const KUser &user : std::as_const(allUsers)) {
         m_userId->addItem(user.loginName() + QStringLiteral(" (") + user.userId().toString() + QStringLiteral(")"), user.userId().toString());
     }
 
@@ -332,7 +333,7 @@ void Smb4KCustomSettingsEditorWidget::setupView()
 
     QList<KUserGroup> allGroups = KUserGroup::allGroups();
 
-    for (const KUserGroup &group : qAsConst(allGroups)) {
+    for (const KUserGroup &group : std::as_const(allGroups)) {
         m_groupId->addItem(group.name() + QStringLiteral(" (") + group.groupId().toString() + QStringLiteral(")"), group.groupId().toString());
     }
 
@@ -427,12 +428,12 @@ void Smb4KCustomSettingsEditorWidget::setupView()
     QWidget *tab4 = new QWidget(this);
     QGridLayout *tab4Layout = new QGridLayout(tab4);
 
+    tab4->setEnabled(Smb4KSettings::enableWakeOnLAN());
+
     m_macAddressLabel = new QLabel(i18n("MAC Address:"), tab4);
-    m_macAddressLabel->setEnabled(false);
     m_macAddress = new KLineEdit(tab4);
     m_macAddress->setClearButtonEnabled(true);
     m_macAddress->setInputMask(QStringLiteral("HH:HH:HH:HH:HH:HH;_")); // MAC address, see QLineEdit doc
-    m_macAddress->setEnabled(false);
     m_macAddressLabel->setBuddy(m_macAddress);
 
     connect(m_macAddress, &KLineEdit::textChanged, this, &Smb4KCustomSettingsEditorWidget::slotMacAddressChanged);
@@ -451,7 +452,7 @@ void Smb4KCustomSettingsEditorWidget::setupView()
     tab4Layout->addWidget(m_sendPacketBeforeMount, 2, 0, 1, 2);
     tab4Layout->setRowStretch(3, 100);
 
-    addTab(tab4, i18n("Wake-On-LAN Settings"));
+    m_wakeOnLanTabIndex = addTab(tab4, i18n("Wake-On-LAN Settings"));
 }
 #else
 void Smb4KCustomSettingsEditorWidget::setupView()
@@ -461,72 +462,68 @@ void Smb4KCustomSettingsEditorWidget::setupView()
 
 void Smb4KCustomSettingsEditorWidget::setCustomSettings(const Smb4KCustomSettings &settings)
 {
-    m_ipAddress->setText(settings.ipAddress());
-    m_workgroup->setText(settings.workgroupName());
+    m_customSettings = settings;
 
-    if (settings.type() != Host) {
+    m_ipAddress->setText(m_customSettings.ipAddress());
+    m_workgroup->setText(m_customSettings.workgroupName());
+
+    if (m_customSettings.type() != Host) {
         m_alwaysRemountShare->setEnabled(true);
-        m_alwaysRemountShare->setChecked(settings.remount() == Smb4KCustomSettings::RemountAlways);
+        m_alwaysRemountShare->setChecked(m_customSettings.remount() == Smb4KCustomSettings::RemountAlways);
     }
 
 #ifdef Q_OS_LINUX
-    m_useWriteAccess->setChecked(settings.useWriteAccess());
-    m_writeAccess->setCurrentIndex(settings.writeAccess());
+    m_useWriteAccess->setChecked(m_customSettings.useWriteAccess());
+    m_writeAccess->setCurrentIndex(m_customSettings.writeAccess());
 
-    m_useFileSystemPort->setChecked(settings.useFileSystemPort());
-    m_fileSystemPort->setValue(settings.fileSystemPort());
+    m_useFileSystemPort->setChecked(m_customSettings.useFileSystemPort());
+    m_fileSystemPort->setValue(m_customSettings.fileSystemPort());
 
-    m_cifsUnixExtensionSupport->setChecked(settings.cifsUnixExtensionsSupport());
+    m_cifsUnixExtensionSupport->setChecked(m_customSettings.cifsUnixExtensionsSupport());
 #endif
 
-    m_useUserId->setChecked(settings.useUser());
-    int userIndex = m_userId->findData(settings.user().userId().toString());
+    m_useUserId->setChecked(m_customSettings.useUser());
+    int userIndex = m_userId->findData(m_customSettings.user().userId().toString());
     m_userId->setCurrentIndex(userIndex);
 
-    m_useGroupId->setChecked(settings.useGroup());
-    int groupIndex = m_groupId->findData(settings.group().groupId().toString());
+    m_useGroupId->setChecked(m_customSettings.useGroup());
+    int groupIndex = m_groupId->findData(m_customSettings.group().groupId().toString());
     m_groupId->setCurrentIndex(groupIndex);
 
-    m_useFileMode->setChecked(settings.useFileMode());
-    m_fileMode->setText(settings.fileMode());
+    m_useFileMode->setChecked(m_customSettings.useFileMode());
+    m_fileMode->setText(m_customSettings.fileMode());
 
-    m_useDirectoryMode->setChecked(settings.useDirectoryMode());
-    m_directoryMode->setText(settings.directoryMode());
+    m_useDirectoryMode->setChecked(m_customSettings.useDirectoryMode());
+    m_directoryMode->setText(m_customSettings.directoryMode());
 
 #ifdef Q_OS_LINUX
-    m_useSmbMountProtocolVersion->setChecked(settings.useMountProtocolVersion());
-    int mountProtocolVersionIndex = m_smbMountProtocolVersion->findData(settings.mountProtocolVersion());
+    m_useSmbMountProtocolVersion->setChecked(m_customSettings.useMountProtocolVersion());
+    int mountProtocolVersionIndex = m_smbMountProtocolVersion->findData(m_customSettings.mountProtocolVersion());
     m_smbMountProtocolVersion->setCurrentIndex(mountProtocolVersionIndex);
 
-    m_useSecurityMode->setChecked(settings.useSecurityMode());
-    int securityModeIndex = m_securityMode->findData(settings.securityMode());
+    m_useSecurityMode->setChecked(m_customSettings.useSecurityMode());
+    int securityModeIndex = m_securityMode->findData(m_customSettings.securityMode());
     m_securityMode->setCurrentIndex(securityModeIndex);
 #endif
 
-    m_useClientProtocolVersions->setChecked(settings.useClientProtocolVersions());
-    int minimalClientProtocolVersionIndex = m_minimalClientProtocolVersion->findData(settings.minimalClientProtocolVersion());
+    m_useClientProtocolVersions->setChecked(m_customSettings.useClientProtocolVersions());
+    int minimalClientProtocolVersionIndex = m_minimalClientProtocolVersion->findData(m_customSettings.minimalClientProtocolVersion());
     m_minimalClientProtocolVersion->setCurrentIndex(minimalClientProtocolVersionIndex);
-    int maximalClientProtocolVersionIndex = m_maximalClientProtocolVersion->findData(settings.maximalClientProtocolVersion());
+    int maximalClientProtocolVersionIndex = m_maximalClientProtocolVersion->findData(m_customSettings.maximalClientProtocolVersion());
     m_maximalClientProtocolVersion->setCurrentIndex(maximalClientProtocolVersionIndex);
 
-    m_useRemoteSmbPort->setChecked(settings.useSmbPort());
-    m_remoteSmbPort->setValue(settings.smbPort());
+    m_useRemoteSmbPort->setChecked(m_customSettings.useSmbPort());
+    m_remoteSmbPort->setValue(m_customSettings.smbPort());
 
-    m_useKerberos->setChecked(settings.useKerberos());
+    m_useKerberos->setChecked(m_customSettings.useKerberos());
 
-    if (settings.type() == Host) {
-        m_macAddressLabel->setEnabled(Smb4KSettings::enableWakeOnLAN());
-        m_macAddress->setEnabled(Smb4KSettings::enableWakeOnLAN());
-        m_sendPacketBeforeScan->setEnabled(Smb4KSettings::enableWakeOnLAN());
-        m_sendPacketBeforeMount->setEnabled(Smb4KSettings::enableWakeOnLAN());
+    widget(m_wakeOnLanTabIndex)->setEnabled(Smb4KSettings::enableWakeOnLAN());
 
-        m_macAddress->setText(settings.macAddress());
-        m_sendPacketBeforeScan->setChecked(settings.wakeOnLanSendBeforeNetworkScan());
-        m_sendPacketBeforeMount->setChecked(settings.wakeOnLanSendBeforeMount());
+    if (m_customSettings.type() == Host) {
+        m_macAddress->setText(m_customSettings.macAddress());
+        m_sendPacketBeforeScan->setChecked(m_customSettings.wakeOnLanSendBeforeNetworkScan());
+        m_sendPacketBeforeMount->setChecked(m_customSettings.wakeOnLanSendBeforeMount());
     }
-
-    m_customSettings = settings;
-    m_haveCustomSettings = true;
 }
 
 Smb4KCustomSettings Smb4KCustomSettingsEditorWidget::getCustomSettings() const
@@ -578,9 +575,9 @@ Smb4KCustomSettings Smb4KCustomSettingsEditorWidget::getCustomSettings() const
     m_customSettings.setUseKerberos(m_useKerberos->isChecked());
 
     if (m_macAddress->hasAcceptableInput()) {
-        m_customSettings.setMACAddress(m_macAddress->text());
+        m_customSettings.setMacAddress(m_macAddress->text());
     } else {
-        m_customSettings.setMACAddress(QString());
+        m_customSettings.setMacAddress(QString());
     }
     m_customSettings.setWakeOnLanSendBeforeNetworkScan(m_sendPacketBeforeScan->isChecked());
     m_customSettings.setWakeOnLanSendBeforeMount(m_sendPacketBeforeMount->isChecked());
@@ -591,7 +588,6 @@ Smb4KCustomSettings Smb4KCustomSettingsEditorWidget::getCustomSettings() const
 void Smb4KCustomSettingsEditorWidget::clear()
 {
     m_customSettings = Smb4KCustomSettings();
-    m_haveCustomSettings = false;
     setCurrentIndex(0);
 
     m_alwaysRemountShare->setChecked(false);
@@ -637,19 +633,150 @@ void Smb4KCustomSettingsEditorWidget::clear()
     m_useKerberos->setChecked(false);
 
     m_macAddress->clear();
-    m_macAddress->setEnabled(false);
     m_sendPacketBeforeScan->setChecked(false);
-    m_sendPacketBeforeScan->setEnabled(false);
-    m_sendPacketBeforeMount->setChecked(false);
     m_sendPacketBeforeMount->setChecked(false);
+
+    widget(m_wakeOnLanTabIndex)->setEnabled(Smb4KSettings::enableWakeOnLAN());
+}
+
+bool Smb4KCustomSettingsEditorWidget::hasDefaultCustomSettings() const
+{
+    return m_hasDefaultCustomSettings;
 }
 
 void Smb4KCustomSettingsEditorWidget::checkValues()
 {
-    if (!m_haveCustomSettings) {
-        return;
+    // Reset m_hasDefaultCustomSettings for this check.
+    m_hasDefaultCustomSettings = true;
+
+    // Check against default values. We won't check the URL, IP address
+    // and workgroup name, because those settings aren't pre-defined.
+    Smb4KCustomSettings defaultCustomSettings;
+
+    switch (defaultCustomSettings.remount()) {
+    case Smb4KCustomSettings::RemountAlways: {
+        if (!m_alwaysRemountShare->isChecked()) {
+            m_hasDefaultCustomSettings = false;
+        }
+        break;
+    }
+    default: {
+        if (m_alwaysRemountShare->isChecked()) {
+            m_hasDefaultCustomSettings = false;
+        }
+        break;
+    }
     }
 
+#ifdef Q_OS_LINUX
+    if (m_useWriteAccess->isChecked() != defaultCustomSettings.useWriteAccess()) {
+        m_hasDefaultCustomSettings = false;
+    }
+
+    if (m_writeAccess->currentIndex() != defaultCustomSettings.writeAccess()) {
+        m_hasDefaultCustomSettings = false;
+    }
+
+    if (m_useFileSystemPort->isChecked() != defaultCustomSettings.useFileSystemPort()) {
+        m_hasDefaultCustomSettings = false;
+    }
+
+    if (m_fileSystemPort->value() != defaultCustomSettings.fileSystemPort()) {
+        m_hasDefaultCustomSettings = false;
+    }
+
+    if (m_cifsUnixExtensionSupport->isChecked() != defaultCustomSettings.cifsUnixExtensionsSupport()) {
+        m_hasDefaultCustomSettings = false;
+    }
+#endif
+
+    if (m_useUserId->isChecked() != defaultCustomSettings.useUser()) {
+        m_hasDefaultCustomSettings = false;
+    }
+
+    if (m_userId->currentData().toString() != defaultCustomSettings.user().userId().toString()) {
+        m_hasDefaultCustomSettings = false;
+    }
+
+    if (m_useGroupId->isChecked() != defaultCustomSettings.useGroup()) {
+        m_hasDefaultCustomSettings = false;
+    }
+
+    if (m_groupId->currentData().toString() != defaultCustomSettings.group().groupId().toString()) {
+        m_hasDefaultCustomSettings = false;
+    }
+
+    if (m_useFileMode->isChecked() != defaultCustomSettings.useFileMode()) {
+        m_hasDefaultCustomSettings = false;
+    }
+
+    if (m_fileMode->text() != defaultCustomSettings.fileMode()) {
+        m_hasDefaultCustomSettings = false;
+    }
+
+    if (m_useDirectoryMode->isChecked() != defaultCustomSettings.useDirectoryMode()) {
+        m_hasDefaultCustomSettings = false;
+    }
+
+    if (m_directoryMode->text() != defaultCustomSettings.directoryMode()) {
+        m_hasDefaultCustomSettings = false;
+    }
+
+#ifdef Q_OS_LINUX
+    if (m_useSmbMountProtocolVersion->isChecked() != defaultCustomSettings.useMountProtocolVersion()) {
+        m_hasDefaultCustomSettings = false;
+    }
+
+    if (m_smbMountProtocolVersion->currentData().toInt() != defaultCustomSettings.mountProtocolVersion()) {
+        m_hasDefaultCustomSettings = false;
+    }
+
+    if (m_useSecurityMode->isChecked() != defaultCustomSettings.useSecurityMode()) {
+        m_hasDefaultCustomSettings = false;
+    }
+
+    if (m_securityMode->currentData().toInt() != defaultCustomSettings.securityMode()) {
+        m_hasDefaultCustomSettings = false;
+    }
+#endif
+
+    if (m_useClientProtocolVersions->isChecked() != defaultCustomSettings.useClientProtocolVersions()) {
+        m_hasDefaultCustomSettings = false;
+    }
+
+    if (m_minimalClientProtocolVersion->currentData().toInt() != defaultCustomSettings.minimalClientProtocolVersion()) {
+        m_hasDefaultCustomSettings = false;
+    }
+
+    if (m_maximalClientProtocolVersion->currentData().toInt() != defaultCustomSettings.maximalClientProtocolVersion()) {
+        m_hasDefaultCustomSettings = false;
+    }
+
+    if (m_useRemoteSmbPort->isChecked() != defaultCustomSettings.useSmbPort()) {
+        m_hasDefaultCustomSettings = false;
+    }
+
+    if (m_remoteSmbPort->value() != defaultCustomSettings.smbPort()) {
+        m_hasDefaultCustomSettings = false;
+    }
+
+    if (m_useKerberos->isChecked() != defaultCustomSettings.useKerberos()) {
+        m_hasDefaultCustomSettings = false;
+    }
+
+    if (m_macAddress->hasAcceptableInput() && (m_macAddress->text() != defaultCustomSettings.macAddress())) {
+        m_hasDefaultCustomSettings = false;
+    }
+
+    if (m_sendPacketBeforeScan->isChecked() != defaultCustomSettings.wakeOnLanSendBeforeNetworkScan()) {
+        m_hasDefaultCustomSettings = false;
+    }
+
+    if (m_sendPacketBeforeMount->isChecked() != defaultCustomSettings.wakeOnLanSendBeforeMount()) {
+        m_hasDefaultCustomSettings = false;
+    }
+
+    // Check if the initial values were edited.
     if (m_ipAddress->text() != m_customSettings.ipAddress()) {
         Q_EMIT edited(true);
         return;
@@ -660,9 +787,21 @@ void Smb4KCustomSettingsEditorWidget::checkValues()
         return;
     }
 
-    if (m_alwaysRemountShare->isChecked() != (m_customSettings.remount() == Smb4KCustomSettings::RemountAlways)) {
-        Q_EMIT edited(true);
-        return;
+    switch (m_customSettings.remount()) {
+    case Smb4KCustomSettings::RemountAlways: {
+        if (!m_alwaysRemountShare->isChecked()) {
+            Q_EMIT edited(true);
+            return;
+        }
+        break;
+    }
+    default: {
+        if (m_alwaysRemountShare->isChecked()) {
+            Q_EMIT edited(true);
+            return;
+        }
+        break;
+    }
     }
 
 #ifdef Q_OS_LINUX
@@ -806,7 +945,6 @@ void Smb4KCustomSettingsEditorWidget::slotIpAddressChanged(const QString &text)
 {
     Q_UNUSED(text);
 
-    // FIXME: Propagate IP address to all other shares of this host?
     // FIXME: Check if this is indeed a valid IP address!?
 
     checkValues();
@@ -986,8 +1124,8 @@ void Smb4KCustomSettingsEditorWidget::slotMacAddressChanged(const QString &text)
 {
     Q_UNUSED(text);
 
-    m_sendPacketBeforeScan->setEnabled(!text.isEmpty() && m_macAddress->hasAcceptableInput());
-    m_sendPacketBeforeMount->setEnabled(!text.isEmpty() && m_macAddress->hasAcceptableInput());
+    m_sendPacketBeforeScan->setEnabled(!m_macAddress->text().isEmpty() && m_macAddress->hasAcceptableInput());
+    m_sendPacketBeforeMount->setEnabled(!m_macAddress->text().isEmpty() && m_macAddress->hasAcceptableInput());
 
     checkValues();
 }
