@@ -14,7 +14,6 @@
 #include "core/smb4ksynchronizer.h"
 #include "smb4kbookmarkdialog.h"
 #include "smb4kcustomsettingseditor.h"
-#include "smb4kpassworddialog.h"
 #include "smb4ksharesview.h"
 #include "smb4ksharesviewitem.h"
 #include "smb4ksynchronizationdialog.h"
@@ -34,6 +33,7 @@
 #include <QPointer>
 
 // KDE includes
+#include <KIO/CopyJob>
 #include <KIO/DropJob>
 #include <KIconLoader>
 #include <KJobUiDelegate>
@@ -99,7 +99,7 @@ void Smb4KSharesViewDockWidget::loadSettings()
         } else if (selectedItems.size() > 1) {
             int foreign = 0;
 
-            for (QListWidgetItem *selectedItem : qAsConst(selectedItems)) {
+            for (QListWidgetItem *selectedItem : std::as_const(selectedItems)) {
                 Smb4KSharesViewItem *item = static_cast<Smb4KSharesViewItem *>(selectedItem);
 
                 if (item && item->shareItem()->isForeign()) {
@@ -264,7 +264,7 @@ void Smb4KSharesViewDockWidget::setupActions()
     //
     QList<QAction *> actionsList = m_actionCollection->actions();
 
-    for (QAction *action : qAsConst(actionsList)) {
+    for (QAction *action : std::as_const(actionsList)) {
         m_contextMenu->addAction(action);
     }
 }
@@ -313,7 +313,7 @@ void Smb4KSharesViewDockWidget::slotItemSelectionChanged()
         int inaccessible = 0;
         int foreign = 0;
 
-        for (QListWidgetItem *selectedItem : qAsConst(selectedItems)) {
+        for (QListWidgetItem *selectedItem : std::as_const(selectedItems)) {
             Smb4KSharesViewItem *item = static_cast<Smb4KSharesViewItem *>(selectedItem);
 
             if (item) {
@@ -473,7 +473,7 @@ void Smb4KSharesViewDockWidget::slotUnmountActionTriggered(bool checked)
     QList<QListWidgetItem *> selectedItems = m_sharesView->selectedItems();
     QList<SharePtr> shares;
 
-    for (QListWidgetItem *selectedItem : qAsConst(selectedItems)) {
+    for (QListWidgetItem *selectedItem : std::as_const(selectedItems)) {
         Smb4KSharesViewItem *item = static_cast<Smb4KSharesViewItem *>(selectedItem);
 
         if (item) {
@@ -498,7 +498,7 @@ void Smb4KSharesViewDockWidget::slotBookmarkActionTriggered(bool checked)
     QList<QListWidgetItem *> selectedItems = m_sharesView->selectedItems();
     QList<SharePtr> shares;
 
-    for (QListWidgetItem *selectedItem : qAsConst(selectedItems)) {
+    for (QListWidgetItem *selectedItem : std::as_const(selectedItems)) {
         Smb4KSharesViewItem *item = static_cast<Smb4KSharesViewItem *>(selectedItem);
         shares << item->shareItem();
     }
@@ -518,7 +518,7 @@ void Smb4KSharesViewDockWidget::slotAddCustomSettingsTriggered(bool checked)
 
     QList<QListWidgetItem *> selectedItems = m_sharesView->selectedItems();
 
-    for (QListWidgetItem *selectedItem : qAsConst(selectedItems)) {
+    for (QListWidgetItem *selectedItem : std::as_const(selectedItems)) {
         Smb4KSharesViewItem *item = static_cast<Smb4KSharesViewItem *>(selectedItem);
 
         QPointer<Smb4KCustomSettingsEditor> customSettingsEditor = new Smb4KCustomSettingsEditor(this);
@@ -536,7 +536,7 @@ void Smb4KSharesViewDockWidget::slotSynchronizeActionTriggered(bool checked)
 
     QList<QListWidgetItem *> selectedItems = m_sharesView->selectedItems();
 
-    for (QListWidgetItem *selectedItem : qAsConst(selectedItems)) {
+    for (QListWidgetItem *selectedItem : std::as_const(selectedItems)) {
         Smb4KSharesViewItem *item = static_cast<Smb4KSharesViewItem *>(selectedItem);
 
         if (item && !item->shareItem()->isInaccessible() && !Smb4KSynchronizer::self()->isRunning(QUrl::fromLocalFile(item->shareItem()->path()))) {
@@ -556,7 +556,7 @@ void Smb4KSharesViewDockWidget::slotKonsoleActionTriggered(bool checked)
 
     QList<QListWidgetItem *> selectedItems = m_sharesView->selectedItems();
 
-    for (QListWidgetItem *selectedItem : qAsConst(selectedItems)) {
+    for (QListWidgetItem *selectedItem : std::as_const(selectedItems)) {
         Smb4KSharesViewItem *item = static_cast<Smb4KSharesViewItem *>(selectedItem);
 
         if (item && !item->shareItem()->isInaccessible()) {
@@ -571,7 +571,7 @@ void Smb4KSharesViewDockWidget::slotFileManagerActionTriggered(bool checked)
 
     QList<QListWidgetItem *> selectedItems = m_sharesView->selectedItems();
 
-    for (QListWidgetItem *selectedItem : qAsConst(selectedItems)) {
+    for (QListWidgetItem *selectedItem : std::as_const(selectedItems)) {
         Smb4KSharesViewItem *item = static_cast<Smb4KSharesViewItem *>(selectedItem);
 
         if (item && !item->shareItem()->isInaccessible()) {
